@@ -1,5 +1,4 @@
 #!/bin/sh
-set -x
 # find out where the build script is located
 tdir=`echo "$0" | sed 's%[\\/][^\\/][^\\/]*$%%'`
 test "x$tdir" = "x$0" && tdir=.
@@ -90,10 +89,8 @@ JAVA_DIRS="${SOURCE_DIRECTORY}/gcc/java ${SOURCE_DIRECTORY}/libjava ${SOURCE_DIR
 OBJECTIVEC_DIRS="${SOURCE_DIRECTORY}/gcc/objc ${SOURCE_DIRECTORY}/libobjc"
 TESTSUITE_DIRS="${SOURCE_DIRECTORY}/gcc/testsuite"
 GPC_DIRS="${SOURCE_DIRECTORY}/gcc/p"
-GM2_DIRS="${SOURCE_DIRECTORY}/gcc/gm2"
-GDC_DIRS="${srcdir}/gcc/d"
 
-# all available = ada,c,c++,f77,gm2,java,objc,pascal
+# all available = c,c++,d,f77,objc,ada,java,pascal
 # additional languages added later
 languages_to_build="c"
 
@@ -101,15 +98,10 @@ all_source_packages="${PKG}-core-${VER}.tar.bz2\
  ${PKG}-ada-${VER}.tar.bz2\
  ${PKG}-g++-${VER}.tar.bz2\
  ${PKG}-g77-${VER}.tar.bz2\
- ${PKG}-gdc-${VER}.tar.bz2\
- ${PKG}-gpc-${VER}.tar.bz2\
  ${PKG}-java-${VER}.tar.bz2\
  ${PKG}-objc-${VER}.tar.bz2\
  ${PKG}-testsuite-${VER}.tar.bz2"
 
-# Modula 2 discontinued
-#  ${PKG}-gm2-${VER}.tar.bz2\
-
 # This is the main DESTDIR target:
 PKG1=${instdir}/package-gcc
 
@@ -164,7 +156,6 @@ extract() {
      tar xvjf ${PKG}-testsuite-${VER}.tar.bz2
    fi )
 }
-
 extract_for_patch() {
   (cd ${srcdir} && \
    tar xvjf ${topdir}/${PKG}-core-${VER}.tar.bz2 && \
@@ -197,7 +188,6 @@ extract_for_patch() {
    fi && \
    mv ${PKG}-${VER} ../${PKG}-${VER}-${REL}-orig )
 }
-
 prep() {
   (cd ${topdir} && \
   mountpwd && \
@@ -208,7 +198,6 @@ prep() {
     (cd ${PKG}-${VER}-${REL}; patch -Z -p1<../${src_patch_name}) ;\
   fi )
 }
-
 mountpwd() {
   (mount -f -s -o managed ${mount_base} ${mount_target} && \
    mount -f -u -o managed ${mount_base} ${mount_target} )
@@ -217,7 +206,6 @@ unmount() {
   (umount -s  ${mount_target} && \
    umount -u  ${mount_target} )
 }
-
 # configure is interactive when building pascal front end
 conf() {
   (# check which front ends are available to build
@@ -233,8 +221,8 @@ conf() {
    if [ -d ${PKG}-${VER}-${REL}/gcc/f ] ; then
      languages_to_build="${languages_to_build},f77"
    fi
-   if [ -d ${PKG}-${VER}-${REL}/gcc/gm2 ] ; then
-     languages_to_build="${languages_to_build},gm2"
+   if [ -d ${PKG}-${VER}-${REL}/gcc/p ] ; then
+     languages_to_build="${languages_to_build},pascal"
    fi
    if [ -d ${PKG}-${VER}-${REL}/gcc/java ] ; then
      languages_to_build="${languages_to_build},java"
@@ -242,9 +230,6 @@ conf() {
    if [ -d ${PKG}-${VER}-${REL}/gcc/objc ] ; then
      languages_to_build="${languages_to_build},objc"
    fi
-   if [ -d ${PKG}-${VER}-${REL}/gcc/p ] ; then
-     languages_to_build="${languages_to_build},pascal"
-   fi
    cd ${objdir} && \
        CFLAGS=${MY_CFLAGS} \
        CXXFLAGS=${MY_CXXFLAGS} \
@@ -284,7 +269,6 @@ reconf() {
   mkdir -p ${objdir} && \
   conf )
 }
-
 build() {
   (cd ${objdir} && \
        CFLAGS=${MY_CFLAGS} \
@@ -300,7 +284,7 @@ build() {
        GNATLIBCFLAGS=${MY_GNATLIBCFLAGS} \
    make \
        prefix=${prefix} exec_prefix=${prefix} \
-       bindir=${prefix}/bin libexecdir=${prefix}/sbin \
+       bindir=${prefix}/bin libexecdir=${prefix}/lib \
        libdir=${prefix}/lib sysconfdir=/etc \
        includedir=${prefix}/include mandir=${prefix}/share/man \
        infodir=${prefix}/share/info tooldir=${prefix} \
@@ -318,26 +302,27 @@ build_info() {
   (cd ${objdir} && \
      make info )
 }
-
+build_proto() {
+  (cd ${objdir}/gcc && \
+     make proto )
+}
 check() {
   (cd ${objdir} && \
    make -k check | tee ${checkfile} 2>&1 )
 }
-
 clean() {
   (cd ${objdir} && \
    make clean )
 }
-
 install() {
   (cd ${objdir} && \
    make install prefix=${PKG1}${prefix} exec_prefix=${PKG1}${prefix} \
-    bindir=${PKG1}${prefix}/bin libexecdir=${PKG1}${prefix}/sbin \
+    bindir=${PKG1}${prefix}/bin libexecdir=${PKG1}${prefix}/lib \
     libdir=${PKG1}${prefix}/lib sysconfdir=${PKG1}/etc \
     includedir=${PKG1}${prefix}/include mandir=${PKG1}${prefix}/share/man \
     infodir=${PKG1}${prefix}/share/info tooldir=${PKG1}${prefix} && \
    make -i install-info prefix=${PKG1}${prefix} exec_prefix=${PKG1}${prefix} \
-    bindir=${PKG1}${prefix}/bin libexecdir=${PKG1}${prefix}/sbin \
+    bindir=${PKG1}${prefix}/bin libexecdir=${PKG1}${prefix}/lib \
     libdir=${PKG1}${prefix}/lib sysconfdir=${PKG1}/etc \
     includedir=${PKG1}${prefix}/include mandir=${PKG1}${prefix}/share/man \
     infodir=${PKG1}${prefix}/share/info tooldir=${PKG1}${prefix} )
@@ -346,26 +331,24 @@ install2() {
   (cd ${objdir} && \
    rm -f ${PKG1}${prefix}/lib/libiberty.a && \
    ( cd ${PKG1}${prefix}/bin && \
-    if [ !-f ${target}-gcc-${VER}.exe ] ; then \
+    if [ -f ${target}-gcc-${VER}.exe ] ; then \
+      true ; \
+    else
       mv -f ${target}-gcc-${VER} ${target}-gcc-${VER}.exe ; \
     fi && \
     rm -f ${target}-c++.exe  && \
     rm -f ${target}-g++.exe && \
     rm -f ${target}-gcc.exe && \
-    rm -f ${target}-gdc.exe && \
+    rm -f ${target}-gcj.exe && \
+    rm -f ${target}-gcjh.exe && \
     ln -sf g77.exe f77.exe && \
     ln -sf gcc.exe cc.exe && \
     ln -sf g++.exe c++.exe && \
     ln -sf gcc.exe ${target}-gcc.exe && \
     ln -sf g++.exe ${target}-c++.exe && \
     ln -sf g++.exe ${target}-g++.exe && \
-    ln -sf gdc.exe ${target}-gdc.exe && \
-    if [ -f gcj.exe ] ; then \
-      rm -f ${target}-gcj.exe && \
-      rm -f ${target}-gcjh.exe && \
-      ln -sf gcj.exe ${target}-gcj.exe && \
-      ln -sf gcjh.exe ${target}-gcjh.exe ; \
-    fi ) && \
+    ln -sf gcj.exe ${target}-gcj.exe && \
+    ln -sf gcjh.exe ${target}-gcjh.exe ) && \
    ( cd ${PKG1}${prefix}/share/info ; rm -f dir ; gzip -fq9 * ) && \
    ( cd ${PKG1}${prefix}/share/man && \
     gzip -fq9 */* && \
@@ -374,9 +357,7 @@ install2() {
     ln -sf g77.1.gz f77.1.gz && \
     ln -sf gcc.1.gz cc.1.gz && \
     cd ${PKG1}${prefix}/share/info && \
-    if [ -f fastjar.info.gz ] ; then \
-      ln -sf fastjar.info.gz jar.info.gz ; \
-    fi ) && \
+    ln -sf fastjar.info.gz jar.info.gz ) && \
    ( cd ${srcdir} && \
     mkdir -p ${PKG1}${prefix}/share/doc/Cygwin && cp ${topdir}/gcc-core-${VER}-${REL}.README ${PKG1}${prefix}/share/doc/Cygwin && \
     mkdir -p ${PKG1}${prefix}/share/doc/${PKG}-${VER}-${REL} && \
@@ -384,55 +365,28 @@ install2() {
       BUGS COPYING COPYING.LIB ChangeLog FAQ INSTALL MAINTAINERS README* *.html \
       ${PKG1}${prefix}/share/doc/${PKG}-${VER}-${REL} && \
     mkdir -p ${PKG1}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc && \
-    mkdir -p ${PKG2}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc/cp && \
     mkdir -p ${PKG3}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc/f && \
     mkdir -p ${PKG3}${prefix}/share/doc/Cygwin && cp ${topdir}/gcc-g77-${VER}-${REL}.README ${PKG3}${prefix}/share/doc/Cygwin && \
     mkdir -p ${PKG4}${prefix}/share/doc/${PKG}-${VER}-${REL}/gnat && \
     mkdir -p ${PKG4}${prefix}/share/doc/Cygwin && cp ${topdir}/gcc-ada-${VER}-${REL}.README ${PKG4}${prefix}/share/doc/Cygwin && \
-    mkdir -p ${PKG5}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc/java && \
     mkdir -p ${PKG6}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc/objc && \
     mkdir -p ${PKG6}${prefix}/share/doc/Cygwin && cp ${topdir}/gcc-objc-${VER}-${REL}.README ${PKG6}${prefix}/share/doc/Cygwin && \
-    mkdir -p ${PKG7}${prefix}/share/doc/Cygwin && cp ${topdir}/gcc-gpc-${VER}-${REL}.README ${PKG7}${prefix}/share/doc/Cygwin && \
-    if [ -f ${PKG1}${prefix}/bin/gm2.exe ] ; then \
-      mkdir -p ${PKG8}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc/gm2 && \
-      mkdir -p ${PKG8}${prefix}/share/doc/Cygwin && cp ${topdir}/gcc-gm2-${VER}-${REL}.README ${PKG8}${prefix}/share/doc/Cygwin ; \
-    fi && \
-    mkdir -p ${PKG9}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc/d && \
-    mkdir -p ${PKG9}${prefix}/share/doc/Cygwin && cp ${topdir}/gcc-gdc-${VER}-${REL}.README ${PKG9}${prefix}/share/doc/Cygwin && \
     ( cd gcc && \
       cp -a \
-        ABOUT* COPYING* LANGUAGES ONEWS README* SERVICE FSF* ChangeLog ChangeLog.cygwin-mingw \
+        ABOUT* COPYING* LANG* ONEWS README* SERVICE \
         ${PKG1}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc && \
       cd f && \
       cp -a \
-        BUGS NEWS ChangeLog \
+        BUGS NEWS \
         ${PKG3}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc/f && \
-      cd ../cp && \
-      cp -a \
-        NEWS ChangeLog \
-        ${PKG2}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc/cp && \
-      cd ../java && \
-      cp -a \
-        ChangeLog \
-        ${PKG5}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc/java && \
       cd ../objc && \
       cp -a \
         README \
         ${PKG6}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc/objc && \
       cd ../ada && \
       cp -a \
-        ChangeLog ChangeLog.cygwin-mingw \
-        ${PKG4}${prefix}/share/doc/${PKG}-${VER}-${REL}/gnat && \
-      if [ -f ${PKG1}${prefix}/bin/gm2.exe ] ; then \
-        cd ../gm2 && \
-        cp -a \
-          ChangeLog README TODO \
-          ${PKG8}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc/gm2 ; \
-      fi && \
-      cd ../d && \
-      cp -a \
-        ChangeLog.pub README INSTALL gpl.txt \
-        ${PKG9}${prefix}/share/doc/${PKG}-${VER}-${REL}/gcc/d ) && \
+        ChangeLog \
+        ${PKG4}${prefix}/share/doc/${PKG}-${VER}-${REL}/gnat ) && \
     mkdir -p ${PKG5}${prefix}/share/doc/${PKG}-${VER}-${REL}/fastjar && \
     mkdir -p ${PKG5}${prefix}/share/doc/Cygwin && cp ${topdir}/gcc-java-${VER}-${REL}.README ${PKG5}${prefix}/share/doc/Cygwin && \
     ( cd fastjar && \
@@ -459,46 +413,33 @@ install2() {
             COPYING.LIB PROJECTS README \
             ${PKG3}${prefix}/share/doc/${PKG}-${VER}-${REL}/libf2c/libU77 )) && \
     mkdir -p ${PKG5}${prefix}/share/doc/${PKG}-${VER}-${REL}/libjava && \
-    mkdir -p ${PKG5}${prefix}/share/doc/${PKG}-${VER}-${REL}/libffi && \
-    mkdir -p ${PKG5}${prefix}/share/doc/${PKG}-${VER}-${REL}/boehm-gc && \
     ( cd libjava && \
       cp -a \
-        COPYING ChangeLog ChangeLog.cygwin-mingw HACKING LIBGCJ_LICENSE NEWS README THANKS \
-        ${PKG5}${prefix}/share/doc/${PKG}-${VER}-${REL}/libjava && \
-      cd ../boehm-gc && \
-      cp -a \
-        ChangeLog ChangeLog.cygwin-mingw doc/* \
-        ${PKG5}${prefix}/share/doc/${PKG}-${VER}-${REL}/boehm-gc && \
-      cd ../libffi && \
-      cp -a \
-        ChangeLog ChangeLog.libgcj LICENSE README \
-        ${PKG5}${prefix}/share/doc/${PKG}-${VER}-${REL}/libffi  ) && \
+        COPYING ChangeLog HACKING LIBGCJ_LICENSE NEWS README THANKS \
+        ${PKG5}${prefix}/share/doc/${PKG}-${VER}-${REL}/libjava  ) && \
     mkdir -p ${PKG6}${prefix}/share/doc/${PKG}-${VER}-${REL}/libobjc && \
     ( cd libobjc && \
       cp -a \
-        ChangeLog README README.threads THREADS THREADS.MACH \
+        README README.threads THREADS THREADS.MACH \
         ${PKG6}${prefix}/share/doc/${PKG}-${VER}-${REL}/libobjc ) && \
     mkdir -p ${PKG2}${prefix}/share/doc/${PKG}-${VER}-${REL}/libstdc++-v3 && \
     mkdir -p ${PKG2}${prefix}/share/doc/Cygwin && cp ${topdir}/gcc-g++-${VER}-${REL}.README ${PKG2}${prefix}/share/doc/Cygwin && \
     ( cd libstdc++-v3 && \
       cp -a \
-        ChangeLog ChangeLog.cygwin-mingw README \
+        ChangeLog README \
         ${PKG2}${prefix}/share/doc/${PKG}-${VER}-${REL}/libstdc++-v3 && \
       cp -a \
         docs/html \
         ${PKG2}${prefix}/share/doc/${PKG}-${VER}-${REL}/libstdc++-v3  ) ) && \
-    mkdir -p ${PKG7}/usr/share/doc/${PKG}-${VER}-${REL}/ && \
-    mv ${PKG1}/usr/doc/gpc ${PKG7}/usr/share/doc/${PKG}-${VER}-${REL}/ && \
-    rm -rf ${PKG1}/usr/doc )
+  )
 }
-
 strip_exe() {
   (cd ${instdir} && \
     find . | xargs file | grep "MS Windows PE 32-bit Intel 80386 console executable not relocatable" | grep 80386 | cut -f 1 -d : | xargs strip --strip-unneeded
-    find ${PKG1}/usr/lib/gcc-lib -name "*.a" | xargs strip -g && \
+    find ${PKG1}/usr/lib/gcc -name "*.a" | xargs strip -g && \
+    touch ${PKG1}/usr/lib/libgcj.a && \
    true )
 }
-
 pre_pkg() {
   (cd ${instdir} && \
    ( cd ${PKG1} && \
@@ -514,8 +455,8 @@ pre_pkg() {
       mv ${PKG1}/usr/include/c++ usr/include && \
       mkdir -p usr/lib && \
       mv ${PKG1}/usr/lib/*++* usr/lib && \
-      mkdir -p usr/lib/gcc-lib/${target}/${VER} && \
-      mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/cc1plus.exe usr/lib/gcc-lib/${target}/${VER} && \
+      mkdir -p usr/lib/gcc/${target}/${VER} && \
+      mv ${PKG1}/usr/lib/gcc/${target}/${VER}/cc1plus.exe usr/lib/gcc/${target}/${VER} && \
       mkdir -p usr/share/man/man1 && \
       mv ${PKG1}/usr/share/man/man1/*++* usr/share/man/man1 )
     ( cd ${PKG3} && \
@@ -526,138 +467,112 @@ pre_pkg() {
       mkdir -p usr/lib && \
       mv ${PKG1}/usr/lib/libfrtbegin.a usr/lib && \
       mv ${PKG1}/usr/lib/libg2c* usr/lib && \
-      mkdir -p usr/lib/gcc-lib/${target}/${VER}/include && \
-      mkdir -p usr/lib/gcc-lib/${target}/${VER} && \
-      mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/f771.exe usr/lib/gcc-lib/${target}/${VER} && \
-      mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/include/g2c.h usr/lib/gcc-lib/${target}/${VER}/include && \
+      mkdir -p usr/lib/gcc/${target}/${VER}/include && \
+      mkdir -p usr/lib/gcc/${target}/${VER} && \
+      mv ${PKG1}/usr/lib/gcc/${target}/${VER}/f771.exe usr/lib/gcc/${target}/${VER} && \
+      mv ${PKG1}/usr/lib/gcc/${target}/${VER}/include/g2c.h usr/lib/gcc/${target}/${VER}/include && \
       mkdir -p usr/share/man/man1 && \
       mv ${PKG1}/usr/share/man/man1/*77* usr/share/man/man1 )
     ( cd ${PKG4} && \
       mkdir -p usr/bin && \
       mv ${PKG1}/usr/bin/gnat* usr/bin && \
+      mv ${PKG1}/usr/bin/gpr* usr/bin && \
+      mv ${PKG1}/usr/share/gnat usr/share/ && \
       mkdir -p usr/share/info && \
       mv ${PKG1}/usr/share/info/gnat* usr/share/info && \
-      mkdir -p usr/lib/gcc-lib/${target}/${VER} && \
-      mkdir -p usr/lib/gcc-lib/${target}/${VER} && \
-      mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/gnat1.exe usr/lib/gcc-lib/${target}/${VER} && \
-      mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/adainclude usr/lib/gcc-lib/${target}/${VER} && \
-      mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/adalib usr/lib/gcc-lib/${target}/${VER} )
+      mkdir -p usr/lib/gcc/${target}/${VER} && \
+      mkdir -p usr/lib/gcc/${target}/${VER} && \
+      mv ${PKG1}/usr/lib/gcc/${target}/${VER}/gnat1.exe usr/lib/gcc/${target}/${VER} && \
+      mv ${PKG1}/usr/lib/gcc/${target}/${VER}/adainclude usr/lib/gcc/${target}/${VER} && \
+      mv ${PKG1}/usr/lib/gcc/${target}/${VER}/adalib usr/lib/gcc/${target}/${VER} )
     ( cd ${PKG5} && \
-      if [ -f ${PKG1}/usr/bin/addr2name.awk ] ; then \
-        mkdir -p usr/bin && \
-        mv ${PKG1}/usr/bin/addr2name.awk usr/bin && \
-        mv ${PKG1}/usr/bin/*gcj* usr/bin && \
-        mv ${PKG1}/usr/bin/gij.exe usr/bin && \
-        mv ${PKG1}/usr/bin/grepjar.exe usr/bin && \
-        mv ${PKG1}/usr/bin/jar.exe usr/bin && \
-        mv ${PKG1}/usr/bin/jcf-dump.exe usr/bin && \
-        mv ${PKG1}/usr/bin/jv-* usr/bin && \
-        mv ${PKG1}/usr/bin/rmi* usr/bin && \
-        mkdir -p usr/include && \
-        mv ${PKG1}/usr/include/gcj usr/include && \
-        mv ${PKG1}/usr/include/gnu usr/include && \
-        mv ${PKG1}/usr/include/java usr/include && \
-        mv ${PKG1}/usr/include/javax usr/include && \
-        mv ${PKG1}/usr/include/jni.h usr/include && \
-        mv ${PKG1}/usr/include/jvmpi.h usr/include && \
-        mv ${PKG1}/usr/include/ffi.h usr/include && \
-        mkdir -p usr/share/info && \
-        mv ${PKG1}/usr/share/info/gcj.* usr/share/info && \
-        mv ${PKG1}/usr/share/info/fastjar.info.gz usr/share/info && \
-        mv ${PKG1}/usr/share/info/jar.info.gz usr/share/info && \
-        mkdir -p usr/lib/gcc-lib/${target}/${VER}/include && \
-        mv ${PKG1}/usr/lib/libgcj* usr/lib && \
-        mv ${PKG1}/usr/lib/libffi* usr/lib && \
-        mv ${PKG1}/usr/lib/lib-org* usr/lib && \
-        mv ${PKG1}/usr/lib/security usr/lib && \
-        mkdir -p usr/lib/gcc-lib/${target}/${VER} && \
-        mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/jc1.exe usr/lib/gcc-lib/${target}/${VER} && \
-        mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/jvgenmain.exe usr/lib/gcc-lib/${target}/${VER} && \
-        mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/include/gcj usr/lib/gcc-lib/${target}/${VER}/include && \
-        mkdir -p usr/share/man/man1 && \
-        mv ${PKG1}/usr/share/man/man1/gcj.1.gz usr/share/man/man1 && \
-        mv ${PKG1}/usr/share/man/man1/gcjh.1.gz usr/share/man/man1 && \
-        mv ${PKG1}/usr/share/man/man1/gij.1.gz usr/share/man/man1 && \
-        mv ${PKG1}/usr/share/man/man1/grepjar.1.gz usr/share/man/man1 && \
-        mv ${PKG1}/usr/share/man/man1/jar.1.gz usr/share/man/man1 && \
-        mv ${PKG1}/usr/share/man/man1/jcf-dump.1.gz usr/share/man/man1 && \
-        mv ${PKG1}/usr/share/man/man1/jv-convert.1.gz usr/share/man/man1 && \
-        mv ${PKG1}/usr/share/man/man1/jv-scan.1.gz usr/share/man/man1 && \
-        mv ${PKG1}/usr/share/man/man1/rmic.1.gz usr/share/man/man1 && \
-        mv ${PKG1}/usr/share/man/man1/rmiregistry.1.gz usr/share/man/man1 && \
-        mv ${PKG1}/usr/share/java usr/share ; \
-      fi )
+      mkdir -p usr/bin && \
+      mv ${PKG1}/usr/bin/addr2name.awk usr/bin && \
+      mv ${PKG1}/usr/bin/*gcj* usr/bin && \
+      mv ${PKG1}/usr/bin/gij.exe usr/bin && \
+      mv ${PKG1}/usr/bin/grepjar.exe usr/bin && \
+      mv ${PKG1}/usr/bin/jar.exe usr/bin && \
+      mv ${PKG1}/usr/bin/jcf-dump.exe usr/bin && \
+      mv ${PKG1}/usr/bin/jv-* usr/bin && \
+      mv ${PKG1}/usr/bin/rmi* usr/bin && \
+      mkdir -p usr/include && \
+      mv ${PKG1}/usr/include/gcj usr/include && \
+      mv ${PKG1}/usr/include/gnu usr/include && \
+      mv ${PKG1}/usr/include/java usr/include && \
+      mv ${PKG1}/usr/include/javax usr/include && \
+      mv ${PKG1}/usr/include/jni.h usr/include && \
+      mv ${PKG1}/usr/include/jvmpi.h usr/include && \
+      mv ${PKG1}/usr/include/ffi.h usr/include && \
+      mkdir -p usr/share/info && \
+      mv ${PKG1}/usr/share/info/gcj.* usr/share/info && \
+      mv ${PKG1}/usr/share/info/fastjar.info.gz usr/share/info && \
+      mv ${PKG1}/usr/share/info/jar.info.gz usr/share/info && \
+      mkdir -p usr/lib/gcc/${target}/${VER}/include && \
+      mv ${PKG1}/usr/lib/libgcj* usr/lib && \
+      mv ${PKG1}/usr/lib/libffi* usr/lib && \
+      mv ${PKG1}/usr/lib/lib-org* usr/lib && \
+      mv ${PKG1}/usr/lib/logging.properties usr/lib && \
+      mv ${PKG1}/usr/lib/pkgconfig usr/lib && \
+      mv ${PKG1}/usr/lib/security usr/lib && \
+      mkdir -p usr/lib/gcc/${target}/${VER} && \
+      mv ${PKG1}/usr/lib/gcc/${target}/${VER}/jc1.exe usr/lib/gcc/${target}/${VER} && \
+      mv ${PKG1}/usr/lib/gcc/${target}/${VER}/jvgenmain.exe usr/lib/gcc/${target}/${VER} && \
+      mv ${PKG1}/usr/lib/gcc/${target}/${VER}/include/gcj usr/lib/gcc/${target}/${VER}/include && \
+      mv ${PKG1}/usr/lib/gcc/${target}/${VER}/include/libffi usr/lib/gcc/${target}/${VER}/include && \
+      mkdir -p usr/share/man/man1 && \
+      mv ${PKG1}/usr/share/man/man1/gcj.1.gz usr/share/man/man1 && \
+      mv ${PKG1}/usr/share/man/man1/gcjh.1.gz usr/share/man/man1 && \
+      mv ${PKG1}/usr/share/man/man1/gij.1.gz usr/share/man/man1 && \
+      mv ${PKG1}/usr/share/man/man1/grepjar.1.gz usr/share/man/man1 && \
+      mv ${PKG1}/usr/share/man/man1/jar.1.gz usr/share/man/man1 && \
+      mv ${PKG1}/usr/share/man/man1/jcf-dump.1.gz usr/share/man/man1 && \
+      mv ${PKG1}/usr/share/man/man1/jv-convert.1.gz usr/share/man/man1 && \
+      mv ${PKG1}/usr/share/man/man1/jv-scan.1.gz usr/share/man/man1 && \
+      mv ${PKG1}/usr/share/man/man1/rmic.1.gz usr/share/man/man1 && \
+      mv ${PKG1}/usr/share/man/man1/rmiregistry.1.gz usr/share/man/man1 && \
+      mv ${PKG1}/usr/share/java usr/share )
     ( cd ${PKG6} && \
       mkdir -p usr/lib && \
       mv ${PKG1}/usr/lib/libobjc* usr/lib && \
-      mkdir -p usr/lib/gcc-lib/${target}/${VER}/include && \
-      mkdir -p usr/lib/gcc-lib/${target}/${VER} && \
-      mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/cc1obj.exe usr/lib/gcc-lib/${target}/${VER} && \
-      mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/include/objc usr/lib/gcc-lib/${target}/${VER}/include )
-    ( cd ${PKG7} && \
-      mkdir -p usr/bin && \
-      mv ${PKG1}/usr/bin/binobj.exe usr/bin && \
-      mv ${PKG1}/usr/bin/gpidump.exe usr/bin && \
-      mv ${PKG1}/usr/bin/gpc* usr/bin && \
-      mkdir -p usr/lib/gcc-lib/${target}/${VER} && \
-      mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/*gpc* usr/lib/gcc-lib/${target}/${VER} && \
-      mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/units usr/lib/gcc-lib/${target}/${VER} && \
-      mkdir -p usr/lib/gcc-lib/${target}/${VER}/include && \
-      mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/include/gpc-in-c.h usr/lib/gcc-lib/${target}/${VER}/include && \
-      mkdir -p usr/share/info && \
-      mv ${PKG1}/usr/share/info/gpc* usr/share/info && \
-      mkdir -p usr/share/man/man1 && \
-      mv ${PKG1}/usr/share/man/man1/gp* usr/share/man/man1 )
-    if [ -f ${PKG1}${prefix}/bin/gm2.exe ] ; then \
-     ( cd ${PKG8} && \
-       mkdir -p usr/bin && \
-       mv ${PKG1}/usr/bin/gm2.exe usr/bin && \
-       mkdir -p usr/lib/gcc-lib/${target}/${VER} && \
-       mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/*gm2* usr/lib/gcc-lib/${target}/${VER} ) ; \
-    fi
-    ( cd ${PKG9} && \
-      mkdir -p usr/bin && \
-      mv ${PKG1}/usr/bin/gdc.exe usr/bin && \
-      mv ${PKG1}/usr/bin/i686-pc-cygwin-gdc.exe usr/bin && \
-      mv ${PKG1}/usr/bin/dmd usr/bin && \
-      mkdir -p usr/lib/gcc-lib/${target}/${VER} && \
-      mv ${PKG1}/usr/lib/gcc-lib/${target}/${VER}/cc1d.exe usr/lib/gcc-lib/${target}/${VER} )
+      mkdir -p usr/lib/gcc/${target}/${VER}/include && \
+      mkdir -p usr/lib/gcc/${target}/${VER} && \
+      mv ${PKG1}/usr/lib/gcc/${target}/${VER}/cc1obj.exe usr/lib/gcc/${target}/${VER} && \
+      mv ${PKG1}/usr/lib/gcc/${target}/${VER}/include/objc usr/lib/gcc/${target}/${VER}/include )
     rm -rf ${PKG1}/usr/include )
 }
-
 pkg() {
   (cd ${instdir} && \
    ( cd ${PKG1} && \
     ( cd ${PKG1} && \
       tar cjvf ${topdir}/${PKG}-core-${VER}-${REL}.tar.bz2 usr/ \
     )
-    ( cd ${PKG2} && \
-      if [ -f usr/bin/g++.exe ] ; then \
+    ( if [ -f ${PKG2}/usr/bin/g++.exe ] ; then \
+        cd ${PKG2} && \
         tar cjvf ${topdir}/${PKG}-g++-${VER}-${REL}.tar.bz2 usr/ ; \
       fi  \
     )
-    ( cd ${PKG3} && \
-      if [ -f usr/bin/g77.exe ] ; then \
+    ( if [ -f ${PKG3}/usr/bin/g77.exe ] ; then \
+        cd ${PKG3} && \
         tar cjvf ${topdir}/${PKG}-g77-${VER}-${REL}.tar.bz2 usr/ ; \
       fi  \
     )
-    ( cd ${PKG4} && \
-      if [ -f usr/bin/gnat.exe ] ; then \
+    ( if [ -f ${PKG4}/usr/bin/gnat.exe ] ; then \
+        cd ${PKG4} && \
         tar cjvf ${topdir}/${PKG}-ada-${VER}-${REL}.tar.bz2 usr/ ; \
       fi  \
     )
-    ( cd ${PKG5} && \
-      if [ -f usr/bin/gcj.exe ] ; then \
+    ( if [ -f ${PKG5}/usr/bin/gcj.exe ] ; then \
+        cd ${PKG5} && \
         tar cjvf ${topdir}/${PKG}-java-${VER}-${REL}.tar.bz2 usr/ ; \
       fi  \
     )
-    ( cd ${PKG6} && \
-      if [ -f usr/lib/gcc-lib/i686-pc-cygwin/3.3.3/cc1obj.exe ] ; then \
+    ( if [ -f ${PKG6}/usr/lib/gcc/i686-pc-cygwin/${VER}/cc1obj.exe ] ; then \
+        cd ${PKG6} && \
         tar cjvf ${topdir}/${PKG}-objc-${VER}-${REL}.tar.bz2 usr/ ; \
       fi  \
     )
-    ( cd ${PKG7} && \
-      if [ -f usr/bin/gpc.exe ] ; then \
+    ( if [ -f ${PKG7}/usr/bin/gpc.exe ] ; then \
+        cd ${PKG7} && \
         tar cjvf ${topdir}/${PKG}-gpc-${VER}-${REL}.tar.bz2 usr/ ; \
       fi  \
     )
@@ -666,15 +581,14 @@ pkg() {
         tar cjvf ${topdir}/${PKG}-gm2-${VER}-${REL}.tar.bz2 usr/ ; \
       fi  \
     )
-    ( cd ${PKG9} && \
-      if [ -f usr/bin/gdc.exe ] ; then \
+    ( if [ -f ${PKG9}/usr/bin/gdc.exe ] ; then \
+        cd ${PKG9} && \
         tar cjvf ${topdir}/${PKG}-gdc-${VER}-${REL}-no-libphobos.tar.bz2 usr/ ; \
       fi  \
     )
   )
  )
 }
-
 mkpatch() {
   (cd ${srcdir} && \
   rm -f gcc/d/phobos/lt* && \
@@ -708,10 +622,8 @@ mkpatch() {
     ${srcinstdir}/${src_patch_name} ; \
   rm -rf ${PKG}-${VER}-${REL}-orig  )
 }
-
 spkg() {
-  (mkpatch && \
-  cp -f ${srcinstdir}/${src_patch_name} ./${src_patch_name} && \
+  ( cp -f ${srcinstdir}/${src_patch_name} ./${src_patch_name} && \
   cp ${all_source_packages} ${srcinstdir}/ && \
   cp $0 ${srcinstdir}/`basename $0` && \
   cp ${PKG}-*-${VER}-${REL}.README ${srcinstdir} && \
@@ -730,17 +642,6 @@ spkg() {
   tar cjvf ${topdir}/${PKG}-g77-${VER}-${REL}-src.tar.bz2 \
       ${PKG}-g77-${VER}.tar.bz2 \
       ${PKG}-g77-${VER}-${REL}.README && \
-  tar cjvf ${topdir}/${PKG}-gpc-${VER}-${REL}-src.tar.bz2 \
-      ${PKG}-gpc-${VER}.tar.bz2 \
-      ${PKG}-gpc-${VER}-${REL}.README && \
-  if [ -f ${PKG}-gm2-${VER}.tar.bz2 ] ; then \
-      tar cjvf ${topdir}/${PKG}-gm2-${VER}-${REL}-src.tar.bz2 \
-          ${PKG}-gm2-${VER}.tar.bz2 \
-          ${PKG}-gm2-${VER}-${REL}.README ; \
-  fi && \
-  tar cjvf ${topdir}/${PKG}-gdc-${VER}-${REL}-src.tar.bz2 \
-      ${PKG}-gdc-${VER}.tar.bz2 \
-      ${PKG}-gdc-${VER}-${REL}.README && \
   tar cjvf ${topdir}/${PKG}-java-${VER}-${REL}-src.tar.bz2 \
       ${PKG}-java-${VER}.tar.bz2 \
       ${PKG}-java-${VER}-${REL}.README && \
@@ -755,12 +656,10 @@ spkg() {
       ${src_patch_name} \
       ${PKG}-core-${VER}-${REL}.README  )
 }
-
 finish() {
   (rm -rf ${srcdir} && \
    unmount )
 }
-
 # run the four libphobos targets after the new gcc is installed 
 # in the system to get the libphobos runtime package
 libphobos_conf() {
@@ -803,7 +702,6 @@ libphobos_pkg() {
       tar cjvf ${topdir}/${PKG}-gdc-${VER}-${REL}.tar.bz2 usr/   \
     )
 }
-
 depend() {
   (cd ${instdir} && \
   find ${instdir} -name "*.exe" -o -name "*.dll" | xargs cygcheck | \
@@ -811,7 +709,6 @@ depend() {
   | xargs cygcheck -f | sed 's%^%  %' ; \
   true )
 }
-
 case $1 in
   build)	build ; STATUS=$? ;;
   build_gnatlib_and_tools)	build_gnatlib_and_tools ; STATUS=$? ;;
@@ -831,6 +728,7 @@ case $1 in
   pkg)		pkg ; STATUS=$? ;;
   pre_pkg)	pre_pkg ; STATUS=$? ;;
   prep*)	prep ; STATUS=$? ;;
+  build_proto)	build_proto ; STATUS=$? ;;
   reconf)	reconf ; STATUS=$? ;;
   spkg)		spkg ; STATUS=$? ;;
   strip*)	strip_exe ; STATUS=$? ;;
@@ -842,7 +740,7 @@ case $1 in
   libphobos_clean)	libphobos_clean ; STATUS=$? ;;
   libphobos_install)	libphobos_install ; STATUS=$? ;;
   libphobos_pkg) libphobos_pkg ; STATUS=$? ;;
-  all) build && build_gnatlib_and_tools && \
+  all) prep && conf && build && build_gnatlib_and_tools && \
        build_info && install && strip_exe && install2 && \
        pre_pkg && pkg && spkg ; \
 	  STATUS=$? ;;
@@ -850,3 +748,4 @@ case $1 in
 esac
 exit ${STATUS}
 
+# FIXME: spkg(), pre_pkg(), install2()
